@@ -15,8 +15,7 @@ from selenium.webdriver.support import expected_conditions as ec
 from selenium.webdriver.support.select import Select
 from selenium.webdriver.support.wait import WebDriverWait
 
-from .common import DrissionElement, get_loc_from_str, translate_loc_to_xpath
-from .config import OptionsManager
+from .common import DrissionElement, get_loc_from_str, translate_loc_to_xpath, avoid_duplicate_name
 
 
 class DriverElement(DrissionElement):
@@ -130,7 +129,7 @@ class DriverElement(DrissionElement):
         return self.ele(loc_or_str, mode='all', show_errmsg=show_errmsg, timeout=timeout)
 
     # -----------------以下为driver独占-------------------
-    def click(self, by_js=False) -> bool:
+    def click(self, by_js=None) -> bool:
         """点击"""
         if not by_js:
             for _ in range(10):
@@ -138,15 +137,11 @@ class DriverElement(DrissionElement):
                     self.inner_ele.click()
                     return True
                 except:
-                    # print(e)
                     sleep(0.2)
         # 若点击失败，用js方式点击
-        # print('Click by JS.')
-        try:
+        if by_js is not False:
             self.run_script('arguments[0].click()')
             return True
-        except:
-            raise
 
     def input(self, value, clear: bool = True) -> bool:
         """输入文本"""
@@ -201,12 +196,10 @@ class DriverElement(DrissionElement):
         """元素坐标"""
         return self.inner_ele.location
 
-    def screenshot(self, path: str = None, filename: str = None) -> str:
+    def screenshot(self, path: str, filename: str = None) -> str:
         """元素截图"""
         name = filename or self.tag
-        path = path or OptionsManager().get_value('paths', 'global_tmp_path')
-        if not path:
-            raise IOError('No path specified.')
+        name = avoid_duplicate_name(path, f'{name}.png')
         Path(path).mkdir(parents=True, exist_ok=True)
         # 等待元素加载完成
         if self.tag == 'img':
@@ -214,7 +207,7 @@ class DriverElement(DrissionElement):
                  '&& arguments[0].naturalWidth > 0'
             while not self.run_script(js):
                 pass
-        img_path = f'{path}\\{name}.png'
+        img_path = f'{path}\\{name}'
         self.inner_ele.screenshot(img_path)
         return img_path
 
