@@ -10,8 +10,7 @@ from pathlib import Path
 from random import random
 from time import time
 from typing import Union, List
-from urllib import parse
-from urllib.parse import urlparse
+from urllib.parse import urlparse, quote
 
 from requests_html import HTMLSession, HTMLResponse
 
@@ -62,6 +61,7 @@ class SessionPage(object):
     @property
     def html(self) -> str:
         """获取元素innerHTML，如未指定元素则获取所有源代码"""
+        # return unescape(self.response.html.raw_html.replace(b'\x08', b'').decode()).replace('\xa0', ' ')
         return self.response.html.html
 
     def ele(self, loc_or_ele: Union[tuple, str, SessionElement], mode: str = None, show_errmsg: bool = False) \
@@ -85,25 +85,25 @@ class SessionPage(object):
         """查找符合条件的所有元素"""
         return self.ele(loc, mode='all', show_errmsg=True)
 
-    def get(self, url: str, params: dict = None, go_anyway: bool = False, **kwargs) -> Union[bool, None]:
+    def get(self, url: str, go_anyway: bool = False, **kwargs) -> Union[bool, None]:
         """用get方式跳转到url，调用_make_response()函数生成response对象"""
-        to_url = f'{url}?{parse.urlencode(params)}' if params else url
+        to_url = quote(url, safe='/:&?=%;#@')
         if not url or (not go_anyway and self.url == to_url):
             return
-        self._url = url
+        self._url = to_url
         self._response = self._make_response(to_url, **kwargs)
         if self._response:
             self._response.html.encoding = self._response.encoding  # 修复requests_html丢失编码方式的bug
         self._url_available = True if self._response and self._response.ok else False
         return self._url_available
 
-    def post(self, url: str, params: dict = None, data: dict = None, go_anyway: bool = False, **kwargs) \
+    def post(self, url: str, data: dict = None, go_anyway: bool = False, **kwargs) \
             -> Union[bool, None]:
         """用post方式跳转到url，调用_make_response()函数生成response对象"""
-        to_url = f'{url}?{parse.urlencode(params)}' if params else url
+        to_url = quote(url, safe='/:&?=%;#@')
         if not url or (not go_anyway and self._url == to_url):
             return
-        self._url = url
+        self._url = to_url
         self._response = self._make_response(to_url, mode='post', data=data, **kwargs)
         if self._response:
             self._response.html.encoding = self._response.encoding  # 修复requests_html丢失编码方式的bug
@@ -193,6 +193,7 @@ class SessionPage(object):
         """
         if mode not in ['get', 'post']:
             raise ValueError("mode must be 'get' or 'post'.")
+        url = quote(url, safe='/:&?=%;#@')
 
         # 设置referer和host值
         kwargs_set = set(x.lower() for x in kwargs)
@@ -229,6 +230,8 @@ class SessionPage(object):
                     charset = 'utf-8'
             else:
                 charset = headers['Content-Type'].split('=')[1]
+            # 避免存在退格符导致乱码或解析出错
+            r._content = r.content if 'stream' in kwargs and kwargs['stream'] else r.content.replace(b'\x08', b'\\b')
             r.encoding = charset
             return_value = r
         return return_value
